@@ -1,13 +1,18 @@
 /*
-   This code is not copyrighted and is put in the public domain. It
-   was originally written in Europe and can be freely distributed from
-   any country except the U.S.A. If this code is imported into the U.S.A,
-   it cannot be re-exported from the U.S.A to another country. (This
-   restriction might seem curious but this is what US law requires.)
- */
+  Copyright (c) 1990-2005 Info-ZIP.  All rights reserved.
 
+  See the accompanying file LICENSE, version 2005-Feb-10 or later
+  (the contents of which are also included in zip.h) for terms of use.
+  If, for some reason, both of these files are missing, the Info-ZIP license
+  also may be found at:  ftp://ftp.info-zip.org/pub/infozip/license.html
+*/
+#define __ZIPCLOAK_C
+
+#ifndef UTIL
 #define UTIL
+#endif
 #include "zip.h"
+#define DEFCPYRT        /* main module: enable copyright string defines! */
 #include "revision.h"
 #include "crypt.h"
 #include "ttyio.h"
@@ -16,8 +21,7 @@
 #  include <stdlib.h>
 #endif
 
-
-#ifdef CRYPT   /* defined (or not) in crypt.h */
+#if CRYPT       /* defined (as TRUE or FALSE) in crypt.h */
 
 int main OF((int argc, char **argv));
 
@@ -31,17 +35,21 @@ local char *tempzip;
 local FILE *tempzf;
 
 /* Pointer to CRC-32 table (used for decryption/encryption) */
-ulg near *crc_32_tab;
+#if (!defined(USE_ZLIB) || defined(USE_OWN_CRCTAB))
+ZCONST ulg near *crc_32_tab;
+#else
+ZCONST uLongf *crc_32_tab;
+#endif
 
 /***********************************************************************
  * Issue a message for the error, clean up files and memory, and exit.
  */
 void ziperr(code, msg)
     int code;               /* error code from the ZE_ class */
-    char *msg;              /* message about how it happened */
+    ZCONST char *msg;       /* message about how it happened */
 {
     if (PERR(code)) perror("zipcloak error");
-    fprintf(stderr, "zipcloak error: %s (%s)\n", errors[code-1], msg);
+    fprintf(stderr, "zipcloak error: %s (%s)\n", ziperrors[code-1], msg);
     if (tempzf != NULL) fclose(tempzf);
     if (tempzip != NULL) {
         destroy(tempzip);
@@ -55,7 +63,7 @@ void ziperr(code, msg)
  * Print a warning message to stderr and return.
  */
 void zipwarn(msg1, msg2)
-    char *msg1, *msg2;        /* message strings juxtaposed in output */
+    ZCONST char *msg1, *msg2;   /* message strings juxtaposed in output */
 {
     fprintf(stderr, "zipcloak warning: %s%s\n", msg1, msg2);
 }
@@ -77,37 +85,34 @@ local void handler(sig)
 }
 
 
-static const char *public[] = {
-"The encryption code of this program is not copyrighted and is put in the",
-"public domain. It was originally written in Europe and can be freely",
-"distributed from any country except the U.S.A. If this program is imported",
-"into the U.S.A, it cannot be re-exported from the U.S.A to another country.",
-"The copyright notice of the zip program applies to the rest of the code."
-};
-
 /***********************************************************************
  * Print license information to stdout.
  */
 local void license()
 {
-    extent i;             /* counter for copyright array */
+    extent i;
 
-    for (i = 0; i < sizeof(public)/sizeof(char *); i++) {
-        puts(public[i]);
-    }
-    for (i = 0; i < sizeof(disclaimer)/sizeof(char *); i++) {
-        puts(disclaimer[i]);
-    }
+    for (i = 0; i < sizeof(swlicense)/sizeof(char *); i++)
+        puts(swlicense[i]);
+    putchar('\n');
 }
 
 
-static const char *help_info[] = {
+static ZCONST char *help_info[] = {
 "",
 "ZipCloak %s (%s)",
+#ifdef VM_CMS
+"Usage:  zipcloak [-d] [-b fm] zipfile",
+#else
 "Usage:  zipcloak [-d] [-b path] zipfile",
+#endif
 "  the default action is to encrypt all unencrypted entries in the zip file",
 "  -d   decrypt--decrypt encrypted entries (copy if given wrong password)",
+#ifdef VM_CMS
+"  -b   use \"fm\" as the filemode for the temporary zip file",
+#else
 "  -b   use \"path\" for the temporary zip file",
+#endif
 "  -h   show this help    -v   show version info    -L   show software license"
   };
 
@@ -118,9 +123,6 @@ local void help()
 {
     extent i;             /* counter for help array */
 
-    for (i = 0; i < sizeof(public)/sizeof(char *); i++) {
-        puts(public[i]);
-    }
     for (i = 0; i < sizeof(help_info)/sizeof(char *); i++) {
         printf(help_info[i], VERSION, REVDATE);
         putchar('\n');
@@ -128,9 +130,6 @@ local void help()
 }
 
 
-static const char CompiledWith[] = "Compiled with %s%s for %s%s%s.\n\n";
-                        /* At module level to keep Turbo C++ 1.0 happy !! */
-
 local void version_info()
 /* Print verbose info about program version and compile time options
    to stdout. */
@@ -138,19 +137,19 @@ local void version_info()
   extent i;             /* counter in text arrays */
 
   /* Options info array */
-  static const char *comp_opts[] = {
+  static ZCONST char *comp_opts[] = {
 #ifdef DEBUG
     "DEBUG",
 #endif
-#if defined(CRYPT) && defined(PASSWD_FROM_STDIN)
+#if CRYPT && defined(PASSWD_FROM_STDIN)
     "PASSWD_FROM_STDIN",
-#endif /* CRYPT & PASSWD_FROM_STDIN */
+#endif /* CRYPT && PASSWD_FROM_STDIN */
     NULL
   };
 
   for (i = 0; i < sizeof(copyright)/sizeof(char *); i++)
   {
-    printf(copyright[i], "zip");
+    printf(copyright[i], "zipcloak");
     putchar('\n');
   }
 
@@ -160,74 +159,7 @@ local void version_info()
     putchar('\n');
   }
 
-  printf(CompiledWith,
-
-#ifdef __GNUC__
-      "gcc ", __VERSION__,
-#else
-      "(OS specific) cc ", "",
-#endif
-
-#ifdef RISCOS
-      "RISC OS (Acorn Computers Ltd)",
-#else
-#ifdef AMIGA
-      "AmigaDOS"
-#else
-#ifdef ATARI
-#  ifdef __MINT__
-      "Atari TOS/MiNT",
-#  else
-      "Atari TOS",
-#  endif
-#else
-#ifdef CMS_MVS
-#  ifdef VM_CMS
-      "VM/CMS",
-#  else
-      "MVS",
-#  endif
-#else
-#ifdef __human68k__
-      "Human68k (X68000)",
-#else
-#ifdef DOS
-      "MS-DOS",
-#else
-#ifdef OS2
-      "OS/2",
-#else
-#ifdef TOPS20
-      "TOPS-20",
-#else
-#ifdef UNIX
-      "Unix",
-#else
-#ifdef VMS
-      "VMS",
-#else
-#ifdef WIN32
-      "\n\tWindows 95 / Windows NT (32-bit)",
-#else
-      "[unrecognized OS]",
-#endif /* WIN32 */
-#endif /* VMS */
-#endif /* UNIX */
-#endif /* TOPS20 */
-#endif /* OS2 */
-#endif /* DOS */
-#endif /* __human68k__ */
-#endif /* CMS_MVS */
-#endif /* ATARI */
-#endif /* AMIGA */
-#endif /* RISCOS */
-
-#ifdef __DATE__
-      " on ", __DATE__
-#else
-      "", ""
-#endif
-    );
+  version_local();
 
   puts("ZipCloak special compilation options:");
   for (i = 0; (int)i < (int)(sizeof(comp_opts)/sizeof(char *) - 1); i++)
@@ -236,6 +168,9 @@ local void version_info()
   }
   printf("\t[encryption, version %d.%d%s of %s]\n",
             CR_MAJORVER, CR_MINORVER, CR_BETA_VER, CR_VERSION_DATE);
+
+  for (i = 0; i < sizeof(cryptnote)/sizeof(char *); i++)
+      puts(cryptnote[i]);
 }
 
 
@@ -245,22 +180,25 @@ local void version_info()
  */
 
 int main(argc, argv)
-    int argc;             /* number of tokens in command line */
-    char **argv;          /* command line tokens */
+    int argc;                   /* number of tokens in command line */
+    char **argv;                /* command line tokens */
 {
-    int attr;             /* attributes of zip file */
-    ulg start_offset;     /* start of central directory */
-    int decrypt;          /* decryption flag */
-    int temp_path;        /* 1 if next argument is path for temp files */
-    char passwd[PWLEN+1]; /* password for encryption or decryption */
-    char verify[PWLEN+1]; /* password for encryption or decryption */
-    char *q;              /* steps through option arguments */
-    int r;                /* arg counter */
-    int res;              /* result code */
-    ulg length;           /* length of central directory */
-    FILE *inzip, *outzip; /* input and output zip files */
-    struct zlist far *z;  /* steps through zfiles linked list */
+    int attr;                   /* attributes of zip file */
+    ulg start_offset;           /* start of central directory */
+    int decrypt;                /* decryption flag */
+    int temp_path;              /* 1 if next argument is path for temp files */
+    char passwd[IZ_PWLEN+1];    /* password for encryption or decryption */
+    char verify[IZ_PWLEN+1];    /* password for encryption or decryption */
+    char *q;                    /* steps through option arguments */
+    int r;                      /* arg counter */
+    int res;                    /* result code */
+    ulg length;                 /* length of central directory */
+    FILE *inzip, *outzip;       /* input and output zip files */
+    struct zlist far *z;        /* steps through zfiles linked list */
 
+#ifdef THEOS
+    setlocale(LC_CTYPE, "I");
+#endif
 
     /* If no args, show help */
     if (argc == 1) {
@@ -270,14 +208,16 @@ int main(argc, argv)
 
     init_upper();               /* build case map table */
 
-    crc_32_tab = (ulg near *)get_crc_table();
+    crc_32_tab = get_crc_table();
                                 /* initialize crc table for crypt */
 
     /* Go through args */
     zipfile = tempzip = NULL;
     tempzf = NULL;
+#ifdef SIGINT
     signal(SIGINT, handler);
-#ifdef SIGTERM                /* Some don't have SIGTERM */
+#endif
+#ifdef SIGTERM                  /* Some don't have SIGTERM */
     signal(SIGTERM, handler);
 #endif
     temp_path = decrypt = 0;
@@ -285,7 +225,7 @@ int main(argc, argv)
         if (*argv[r] == '-') {
             if (!argv[r][1]) ziperr(ZE_PARMS, "zip file cannot be stdin");
             for (q = argv[r]+1; *q; q++) {
-                switch(*q) {
+                switch (*q) {
                 case 'b':   /* Specify path for temporary file */
                     if (temp_path) {
                         ziperr(ZE_PARMS, "use -b before zip file name");
@@ -347,18 +287,18 @@ int main(argc, argv)
     }
 
     /* Get password */
-    if (getp("Enter password: ", passwd, PWLEN+1) == NULL)
+    if (getp("Enter password: ", passwd, IZ_PWLEN+1) == NULL)
         ziperr(ZE_PARMS,
                "stderr is not a tty (you may never see this message!)");
 
     if (decrypt == 0) {
-        if (getp("Verify password: ", verify, PWLEN+1) == NULL)
+        if (getp("Verify password: ", verify, IZ_PWLEN+1) == NULL)
                ziperr(ZE_PARMS,
                       "stderr is not a tty (you may never see this message!)");
 
         if (strcmp(passwd, verify))
                ziperr(ZE_PARMS, "password verification failed");
- 
+
         if (*passwd == '\0')
                ziperr(ZE_PARMS, "zero length password not allowed");
     }
@@ -401,14 +341,16 @@ int main(argc, argv)
     /* Write central directory and end of central directory */
 
     /* get start of central */
-    if ((start_offset = ftell(outzip)) == -1L) ziperr(ZE_TEMP, tempzip);
+    if ((start_offset = (ulg)ftell(outzip)) == (ulg)-1L)
+        ziperr(ZE_TEMP, tempzip);
 
     for (z = zfiles; z != NULL; z = z->nxt) {
         if ((res = putcentral(z, outzip)) != ZE_OK) ziperr(res, tempzip);
     }
 
     /* get end of central */
-    if ((length = ftell(outzip)) == -1L) ziperr(ZE_TEMP, tempzip);
+    if ((length = (ulg)ftell(outzip)) == (ulg)-1L)
+        ziperr(ZE_TEMP, tempzip);
 
     length -= start_offset;               /* compute length of central */
     if ((res = putend((int)zcount, length, start_offset, zcomlen,
@@ -426,6 +368,10 @@ int main(argc, argv)
     free((zvoid *)tempzip);
     tempzip = NULL;
     setfileattr(zipfile, attr);
+#ifdef RISCOS
+    /* Set the filetype of the zipfile to &DDC */
+    setfiletype(zipfile, 0xDDC);
+#endif
     free((zvoid *)zipfile);
     zipfile = NULL;
 
@@ -437,21 +383,26 @@ int main(argc, argv)
 int main OF((void));
 
 void zipwarn(msg1, msg2)
-char  *msg1, *msg2;
+ZCONST char  *msg1, *msg2;
 {
+    /* Tell picky compilers to shut up about unused variables */
+    msg1 = msg1; msg2 = msg2;
 }
 
 void ziperr(c, h)
 int  c;
-char *h;
+ZCONST char *h;
 {
+    /* Tell picky compilers to shut up about unused variables */
+    c = c; h = h;
 }
 
 int main()
 {
     fprintf(stderr, "\
-This version of ZipCloak does not support encryption.  Get zcrypt26.zip (or\n\
-a later version) and recompile.  The Info-ZIP file `Where' lists sites.\n");
+This version of ZipCloak does not support encryption.  Get the current Zip\n\
+source distribution and recompile ZipCloak after you have added an option to\n\
+define the symbol USE_CRYPT to the C compiler's command arguments.\n");
     RETURN(1);
 }
 
